float_cols = \
('mass', 'mass_error_min', 'mass_error_max', 
 'mass_sini', 'mass_sini_error_min', 'mass_sini_error_max', 
 'radius', 'radius_error_min', 'radius_error_max', 
 'orbital_period', 'orbital_period_error_min', 'orbital_period_error_max', 
 'semi_major_axis', 'semi_major_axis_error_min', 'semi_major_axis_error_max', 
 'eccentricity', 'eccentricity_error_min', 'eccentricity_error_max', 
 'inclination', 'inclination_error_min', 'inclination_error_max', 
 'angular_distance', 'omega', 'omega_error_min', 'omega_error_max', 
 'tperi', 'tperi_error_min', 'tperi_error_max', 
 'tconj', 'tconj_error_min', 'tconj_error_max', 
 'tzero_tr', 'tzero_tr_error_min', 'tzero_tr_error_max', 
 'tzero_tr_sec', 'tzero_tr_sec_error_min', 'tzero_tr_sec_error_max', 
 'lambda_angle', 'lambda_angle_error_min', 'lambda_angle_error_max', 
 'impact_parameter', 'impact_parameter_error_min', 'impact_parameter_error_max', 
 'tzero_vr', 'tzero_vr_error_min', 'tzero_vr_error_max', 
 'k', 'k_error_min', 'k_error_max', 
 'temp_calculated', 'temp_calculated_error_min', 'temp_calculated_error_max', 
 'temp_measured', 'hot_point_lon', 
 'geometric_albedo', 'geometric_albedo_error_min', 'geometric_albedo_error_max', 
 'log_g', 'mag_v', 'mag_i', 'mag_j', 'mag_h', 'mag_k', 
 'star_distance', 'star_distance_error_min', 'star_distance_error_max', 
 'star_metallicity', 'star_metallicity_error_min', 'star_metallicity_error_max', 
 'star_mass', 'star_mass_error_min', 'star_mass_error_max', 
 'star_radius', 'star_radius_error_min', 'star_radius_error_max', 
 'star_age', 'star_age_error_min', 'star_age_error_max', 
 'star_teff', 'star_teff_error_min', 'star_teff_error_max')